#!/bin/bash

distro=$(awk -F= '/^ID=/{print $2};' /etc/os-release | tr -d '"')
[[ "$distro" == "ubuntu" || "$distro" == "debian" ]] && is_debian=true || is_debian=false
[[ "$distro" == "fedora" ]] && is_fedora=true || is_fedora=false
[[ "$distro" == "rhel" || "$distro" == "centos" ]] && is_centos=true || is_centos=false

if $is_debian; then
  sudo apt update
  sudo apt install -y apt-transport-https ca-certificates curl software-properties-common
  curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
  sudo add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu bionic stable"
  sudo apt update
  sudo apt install -y docker-ce gnupg2 pass
elif $is_centos; then
  sudo yum-config-manager --add-repo https://download.docker.com/linux/centos/docker-ce.repo
  sudo yum install -y docker-ce docker-ce-cli containerd.io
  sudo systemctl start docker
elif $is_fedora; then
  sudo dnf -y install dnf-plugins-core
  sudo dnf config-manager --add-repo https://download.docker.com/linux/fedora/docker-ce.repo
  sudo dnf -y install docker
  sudo systemctl start docker
fi

sudo usermod -aG docker $USER

sudo curl -L "https://github.com/docker/compose/releases/download/1.27.4/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

echo "Updating sys settings"

if $is_debian || $is_centos; then
  sudo sed -i -e '$i \echo never > /sys/kernel/mm/transparent_hugepage/enabled &\n' /etc/rc.local
  sudo sh -c "echo never > /sys/kernel/mm/transparent_hugepage/enabled"
  sudo sh -c "echo 'vm.overcommit_memory = 1' >> /etc/sysctl.conf"
  sudo sysctl vm.overcommit_memory=1
fi

if $is_debian; then
echo "Creating 4G swap file"
sudo fallocate -l 4G /swapfile && \
    sudo chmod 600 /swapfile && \
    sudo mkswap /swapfile && \
    sudo swapon /swapfile && \
    echo "/swapfile none swap sw 0 0" | sudo tee -a /etc/fstab

echo "Increase open file limit"
echo "session required pam_limits.so" | sudo tee -a /etc/pam.d/common-session > /dev/null
echo "session required pam_limits.so" | sudo tee -a /etc/pam.d/common-session-noninteractive > /dev/null
fi

sudo tee -a /etc/security/limits.conf > /dev/null <<EOF
  * soft  nofile 100000
  * hard  nofile 100000
  root soft  nofile 100000
  root hard  nofile 100000
EOF